import {ElTag} from "element-plus";
import {ref} from "vue";
import {ProviderEnum} from "@/views/ai/model/chatModel/composables/provider";
import {FormSchema} from "@/types/form";

export default function () {
  const LLMProviders: any[] = [
    {
      model: ProviderEnum.OPENAI,
      name: 'OpenAI',
      models: ['text-embedding-3-small', 'text-embedding-3-large', 'text-embedding-ada-002'],
    },
    {
      model: ProviderEnum.Q_FAN,
      name: '百度千帆',
      models: ['bge-large-zh', 'bge-large-en', 'tao-8k'],
    },
    {
      model: ProviderEnum.Q_WEN,
      name: '阿里百炼',
      models: ['text-embedding-v3'],
    },
    {
      model: ProviderEnum.ZHIPU,
      name: '智谱清言',
      models: ['embedding-2', 'embedding-3'],
    },
    {
      model: ProviderEnum.DOUYIN,
      name: '抖音豆包',
      models: ['text-240715', 'text-240515'],
    },
    {
      model: ProviderEnum.OLLAMA,
      name: 'Ollama',
      models: ['text2vec-bge-large-chinese:latest'],
    },
  ];
  const baseColumns = [
    {
      label: '模型别名',
     field: 'name',
    },
    {
      label: '模型版本',
     field: 'model',
      width: '160',
    },
    {
      label: '向量纬度',
     field: 'dimension',
      align: 'center',
      width: '100',
      render(row) {
        return h(
          ElTag,
          {
            size: 'small',
          },
          {
            default: () => row.dimension,
          }
        );
      },
    },
    {
      label: 'Api Key',
     field: 'apiKey',
    },
    {
      label: 'Base Url',
     field: 'baseUrl',
    },
  ];
  const tableData = ref([
  ])
  const shema = ref<FormSchema[]>([
    {
      label: '模型名称',
      field: 'name',
      component: 'Select',
      colProps: {
        span: 6
      },
      componentProps: {
        style: {
          width: '150px',
        },
        options: LLMProviders.map((item) => ({
          label: item.name,
          value: item.model,
        })),
      },

    }
  ])
  return {
    baseColumns,
    shema,
    tableData
  }
}
